Printouts — SoL 4 user manual

# Printouts

Hint

Since version 3.33 almost all printouts show a QRCode on the first page containing an hyperlink to the corresponding Lit Page. The QRCode can be either recognized with one of the many freely available app on a smartphone, or simply clicked when viewing the PDF on a traditional computer.

The QRCode does not appear when you use the `localhost` address to access your local instance of SoL, though. If you want it, you must use the IP address of your machine instead: instead of using the URL `http://localhost:6996/` to access SoL, use something like `http://192.168.1.123:6996/` (of course you must determine and use the IP address of the computer where SoL is running) and the QRCode should appear and be usable by other devices connected to your local LAN.

## Participants

## Badges

## Scorecards

## Results

## Ranking